@@ -100,7 +100,10 @@ class ArchAMD64(Arch):
             self._cs_x86_syntax = new_syntax
 
     def _configure_capstone(self):
-        self._cs.syntax = _capstone.CS_OPT_SYNTAX_ATT if self._cs_x86_syntax == 'at&t' else _capstone.CS_OPT_SYNTAX_INTEL
+        if self._cs_x86_syntax == 'at&t':
+            self._cs.syntax = _capstone.CS_OPT_SYNTAX_ATT
+        else:
+            self._cs.syntax = _capstone.CS_OPT_SYNTAX_INTEL
 
     @property
     def keystone_x86_syntax(self):
@@ -198,7 +201,10 @@ class ArchAMD64(Arch):
                  linux_entry_value=0),
         Register(name='rsp', size=8, subregisters=[('esp', 0, 4)], alias_names=('sp',),
                  general_purpose=True, default_value=(initial_sp, True, 'global')),
-        Register(name='rbp', size=8, subregisters=[('ebp', 0, 4), ('bpl', 0, 1), ('bph', 1, 1)], alias_names=('bp',),
+        Register(name='rbp', size=8, subregisters=[('ebp', 0, 4),
+                                                   ('_bp', 0, 2),
+                                                   ('bpl', 0, 1),
+                                                   ('bph', 1, 1)], alias_names=('bp',),
                  general_purpose=True, linux_entry_value=0),
         Register(name='rsi', size=8, subregisters=[('esi', 0, 4),
                                                    ('si', 0, 2),
@@ -256,7 +262,7 @@ class ArchAMD64(Arch):
                  general_purpose=True),
         Register(name='ac', size=8, alias_names=('acflag',),concrete=False),
         Register(name='id', size=8, alias_names=('idflag',)),
-        Register(name='fs', size=8, alias_names=('fs_const',),
+        Register(name='fs', size=8, vex_name='fs_const', alias_names=('fs_const',),
                  default_value=(0x9000000000000000, True, 'global'),concrete=False),
         Register(name='sseround', size=8, vector=True,
                  default_value=(0, False, None)),
@@ -363,8 +369,14 @@ class ArchAMD64(Arch):
         Register(name='cmstart', size=8),
         Register(name='cmlen', size=8),
         Register(name='nraddr', size=8),
-        Register(name='gs', size=8, alias_names=('gs_const',), concrete=False),
+        Register(name='gs', size=8, vex_name='gs_const', alias_names=('gs_const',), concrete=False),
         Register(name='ip_at_syscall', size=8, concrete=False, artificial=True),
+        Register(name='cs_seg', size=2, vex_name='cs'),
+        Register(name='ds_seg', size=2, vex_name='ds'),
+        Register(name='es_seg', size=2, vex_name='es'),
+        Register(name='fs_seg', size=2, vex_name='fs'),
+        Register(name='fs_seg', size=2, vex_name='gs'),
+        Register(name='ss_seg', size=2, vex_name='ss'),
     ]
 
     symbol_type_translation = {
